==> db-0.3.0.jar: db/burningswell-db/migrations/deploy/switch-to-geography.sql <==
-- Deploy switch-to-geography

BEGIN;

ALTER TABLE "time-zones" ALTER COLUMN geom TYPE geography(MULTIPOLYGON, 4326) USING geography(ST_SetSRID(geometry(geom), 4326));
ALTER TABLE airports ALTER COLUMN location TYPE geography(POINT, 4326) USING geography(ST_SetSRID(geometry(location), 4326));
ALTER TABLE continents ALTER COLUMN geom TYPE geography(MULTIPOLYGON, 4326) USING geography(ST_SetSRID(geometry(geom), 4326));
ALTER TABLE continents ALTER COLUMN location TYPE geography(POINT, 4326) USING geography(ST_SetSRID(geometry(location), 4326));
ALTER TABLE countries ALTER COLUMN geom TYPE geography(MULTIPOLYGON, 4326) USING geography(ST_SetSRID(geometry(geom), 4326));
ALTER TABLE countries ALTER COLUMN location TYPE geography(POINT, 4326) USING geography(ST_SetSRID(geometry(location), 4326));
ALTER TABLE photos ALTER COLUMN location TYPE geography(POINT, 4326) USING geography(ST_SetSRID(geometry(location), 4326));
ALTER TABLE ports ALTER COLUMN location TYPE geography(POINT, 4326) USING geography(ST_SetSRID(geometry(location), 4326));
ALTER TABLE regions ALTER COLUMN geom TYPE geography(MULTIPOLYGON, 4326) USING geography(ST_SetSRID(geometry(geom), 4326));
ALTER TABLE regions ALTER COLUMN location TYPE geography(POINT, 4326) USING geography(ST_SetSRID(geometry(location), 4326));
ALTER TABLE spots ALTER COLUMN location TYPE geography(POINT, 4326) USING geography(ST_SetSRID(geometry(location), 4326));
ALTER TABLE users ALTER COLUMN location TYPE geography(POINT, 4326) USING geography(ST_SetSRID(geometry(location), 4326));

COMMIT;

==> db-0.3.26.jar: db/burningswell-db/migrations/deploy/switch-to-geography.sql <==
-- Deploy switch_to_geography

BEGIN;

ALTER TABLE "time_zones" ALTER COLUMN geom TYPE geography(MULTIPOLYGON, 4326) USING geography(ST_SetSRID(geometry(geom), 4326));
ALTER TABLE airports ALTER COLUMN location TYPE geography(POINT, 4326) USING geography(ST_SetSRID(geometry(location), 4326));
ALTER TABLE continents ALTER COLUMN geom TYPE geography(MULTIPOLYGON, 4326) USING geography(ST_SetSRID(geometry(geom), 4326));
ALTER TABLE continents ALTER COLUMN location TYPE geography(POINT, 4326) USING geography(ST_SetSRID(geometry(location), 4326));
ALTER TABLE countries ALTER COLUMN geom TYPE geography(MULTIPOLYGON, 4326) USING geography(ST_SetSRID(geometry(geom), 4326));
ALTER TABLE countries ALTER COLUMN location TYPE geography(POINT, 4326) USING geography(ST_SetSRID(geometry(location), 4326));
ALTER TABLE photos ALTER COLUMN location TYPE geography(POINT, 4326) USING geography(ST_SetSRID(geometry(location), 4326));
ALTER TABLE ports ALTER COLUMN location TYPE geography(POINT, 4326) USING geography(ST_SetSRID(geometry(location), 4326));
ALTER TABLE regions ALTER COLUMN geom TYPE geography(MULTIPOLYGON, 4326) USING geography(ST_SetSRID(geometry(geom), 4326));
ALTER TABLE regions ALTER COLUMN location TYPE geography(POINT, 4326) USING geography(ST_SetSRID(geometry(location), 4326));
ALTER TABLE spots ALTER COLUMN location TYPE geography(POINT, 4326) USING geography(ST_SetSRID(geometry(location), 4326));
ALTER TABLE users ALTER COLUMN location TYPE geography(POINT, 4326) USING geography(ST_SetSRID(geometry(location), 4326));

COMMIT;
